@@ -34,11 +34,11 @@ def respond():
 
 @app.route('/set_webhook', methods=['GET', 'POST'])
 def set_webhook():
-    s = bot.setWebhook('{URL}{HOOK}'.format(URL=webhook_url, HOOK=bot_token))
+    s = bot.setWebhook(webhook_url)
     if s:
-        return "webhook setup ok"
+        return f"Webhook setup OK : {webhook_url}"
     else:
-        return "webhook setup failed"
+        return f"Webhook setup failed : {webhook_url}"
 
 
 @app.route('/')
@@ -47,7 +47,7 @@ def index():
 
 
 def start():
-    app.run(threaded=True, port=webhook_port, host=webhook_host)
+    app.run(threaded=True, port=webhook_port, host=webhook_host, ssl_context=('cert.pem', 'key.pem'))
 
 
 if __name__ == '__main__':
